@@ -51,13 +51,13 @@ use 5.8.0;
 use strict;
 use warnings;
 
-use base qw(NetSDS::App);
+use base 'NetSDS::App';
 
 use CGI::Fast;
 use CGI::Cookie;
 
-use version; our $VERSION = "0.02";
-our @EXPORT_OK = qw();
+use NetSDS;
+use version; our $VERSION = NetSDS->VERSION;
 
 
 #***********************************************************************
