@@ -67,7 +67,8 @@ use Storable qw(nfreeze thaw);
 
 use Data::Structure::Util;
 
-use version; our $VERSION = '1.020';
+use NetSDS;
+use version; our $VERSION = NetSDS->VERSION;
 
 #***********************************************************************
 
