@@ -38,7 +38,8 @@ use warnings;
 
 use Unix::Syslog qw(:macros :subs);
 
-use version; our $VERSION = '1.020';
+use NetSDS;
+use version; our $VERSION = NetSDS->VERSION;
 
 #===============================================================================
 
